Python: module TileStache.Vector.Arc

TileStache.Vector.Arc | index

`Arc-specific Vector provider helpers.`

Functions
`` |  | add(...) `add(a, b) -- Same as a + b.` reserialize_to_arc(content, point_objects) `Convert from "geo" (GeoJSON) to ESRI's GeoServices REST serialization. Second argument is a boolean flag for whether to use the class _amfGeometryMapPoint for points in ring and path arrays, or tuples. The formal class is needed for AMF responses, plain tuples otherwise. Much of this cribbed from sample server queries and page 191+ of: http://www.esri.com/library/whitepapers/pdfs/geoservices-rest-spec.pdf`

Data
`` |  | geometry_types = {'LineString': 'esriGeometryPolyline', 'MultiLineString': 'esriGeometryPolyline', 'MultiPoint': 'esriGeometryMultipoint', 'MultiPolygon': 'esriGeometryPolygon', 'Point': 'esriGeometryPoint', 'Polygon': 'esriGeometryPolygon'} pyamf_classes = {<class 'TileStache.Vector.Arc._amfFeatureSet'>: 'com.esri.ags.tasks.FeatureSet', <class 'TileStache.Vector.Arc._amfSpatialReference'>: 'com.esri.ags.SpatialReference', <class 'TileStache.Vector.Arc._amfFeature'>: 'com.esri.ags.Feature', <class 'TileStache.Vector.Arc._amfGeometryMapPoint'>: 'com.esri.ags.geometry.MapPoint', <class 'TileStache.Vector.Arc._amfGeometryPolyline'>: 'com.esri.ags.geometry.Polyline', <class 'TileStache.Vector.Arc._amfGeometryPolygon'>: 'com.esri.ags.geometry.Polygon'}